@@ -1,5 +1,6 @@
 
 import docker_registry.core.boto as  coreboto
+from docker_registry.core import compat
 from docker_registry.core import driver
 from docker_registry.core import exceptions
 from docker_registry.core import lru
@@ -12,6 +13,7 @@ import logging
 from jss.connection import JssClient
 
 logger = logging.getLogger(__name__)
+json = compat.json
 
 class Storage(driver.Base):
 
